%%% GenerateMediaSchedule
% Create and save the media feeding schedule
% R. Gmez-Sjberg
%%%

% Feeding schedule matrix
% Each row is a different medium schedule,
% corresponding to the 3rd dimention of FeedMatrix
% Each column is a time point.
% The duration of a time point is equal to media_time_base
% Each element corresponds to a medium, which indexes the row
% of MediaInputs

% Log file name
log_file = 'MediaSchedule-log';
% Schedule file name
ScheduleFile = 'MediaSchedule';

% Name of variable to save matrix to
var_name = 'MediaSchedule';

% Media names in order of assignment
MediaNames = {'dmem','ligand'};

% Schedule names in order of assignment
SchNames = {'dmem','ligand'};

% Time period for media switching, in hours
schedule_time_base = 1;

% Total number of days to run
NumDays = 7;

% Number of time base periods in one day
OneDay = 24/schedule_time_base;

% Total number of time base periods
NumPer = NumDays*OneDay;

% Compressed schedule
% Used to build full schedule automatically
% Each row corresponds to a different media schedule
% A schedule is formed by one or more "repetition units" separated by semi-colons.
% A repetition unit is a recursively-defined cell array with two elements separated by a comma:
%   The first element is what should be repeated. This can be either a
%   medium name, or another repetition unit.
%
%   The second element is a number specifying the number of times
%   that the first element should be repeated in the schedule
%
%   If the first element is a medium name, the following rules apply to the
%   interpretation of the second element:
%        This second element corresponds to the number of time bases that the
%        medium is used (the "duration" of the medium).
%
%        A negative duration indicates that the medium should be replaced, not
%        pumped IF it's the same medium as on the previous period. If it's NOT
%        the same medium as in the previous period then it PREVENTS replacement.
%
%        A number of cycles can be specified as 3 digits after the decimal point:
%        i.e. 1.030 in the duration means medium #1, for 30 cycles
%        i.e. 4.105 in the duration means medium #4, for 105 cycles
%        Forcing a medium replacement can also be done by setting the number of
%        cycles to 999 (i.e. 4.999)
% Example:
% Schedule = {
%    {'Bmp4', 10};  % First schedule
%    {{'Bmp4', 10; 'DAPI', -1}, 5; 'PBS', 2.030}; % Second schedule
%    {{{'Bmp4', 10; 'DAPI', -1}, 5; 'PBS', 2.030}, 4}; % Third schedule
% };

Schedule = {
    {'dmem', NumPer};
    {'ligand', NumPer};
    };

try
    disp(' ');
    disp(' ');
    disp('Generating Media Schedule');
    ns = length(Schedule);
    if ns ~= length(SchNames)
        error('length(Schedule) ~= length(SchNames)');
    end
    % Create a report file
    log_fname = [CCCdata.DataPath log_file '.txt'];
    logfid = fopen(log_fname, 'wt');
    fprintf(logfid, '%% %s\n', datestr(clock));
    fprintf(logfid, '%% %s\n', log_fname);
    fprintf(logfid, '%% Feeding schedule\n');
    fprintf(logfid, '%% Schedule file name: %s.mat\n', ScheduleFile);
    fprintf(logfid, '%% schedule_time_base = %f hrs\n', schedule_time_base);
    fprintf(logfid, '%% Media:\n');
    fprintf(logfid, '%% ');
    nm = length(MediaNames);
    for ii = 1:nm
        fprintf(logfid, '%i = %s   ', ii, MediaNames{ii});
    end
    fprintf(logfid, '\n%% Number of days = %3.1f\n', NumDays);
    fprintf(logfid, '%% Hours = ');
    for ii = 1:NumPer
        fprintf(logfid, '\t%4.0f    ', ii);
    end
    fprintf(logfid, '\n');

    % Build cell array
    Matrix = {};
    for ii = 1:ns
        scr_check4stop;
        fprintf('Row = %i\n', ii);
        Matrix{ii, 1} = [];
        clear('ScheduleExpand');
        [Matrix{ii}, ttime] = ScheduleExpand(Schedule{ii}, Matrix{ii}, MediaNames, NumPer, 0);
        if ttime < NumPer
            Matrix{ii} = [Matrix{ii}, ones(1, (NumPer - ttime))];
        elseif ttime > NumPer
            Matrix{ii} = Matrix{ii}(1:NumPer);
        end
        fprintf(logfid, '%s\t-->\t%s\n', SchNames{ii}, num2str(Matrix{ii}, '\t%6.3f'));
        scr_check4stop;
    end

    % Save schedule matrix
    eval([var_name '= Matrix;']);
    schedule_length = NumPer;
    save([CCCdata.DataPath ScheduleFile '.mat'], var_name, 'SchNames', 'MediaNames', 'schedule_time_base', 'schedule_length');
    
    % Plot schedule
    clear('PlotMediaSchedule');
    PlotMediaSchedule;
    
catch
    str = ['Error!' 10 13 lasterr];
    infodlg('Title', 'Feed Schedule', 'String', str);
end

if exist('logfid', 'var') && (logfid > 0)
    disp('Closing log file');
    fclose(logfid);
end
